@@ -176,6 +176,10 @@ sub insert {
     my $self = shift;
     my ( $context ) = validate_pos( @_, { type => HASHREF } );
 
+    return $CELL->status_err( 
+        "DOCHAZKA_PARTIAL_INTERVAL_ILLEGAL_OPERATION" 
+    ) if $self->partial;
+
     my $status = cud( 
         conn => $context->{'dbix_conn'},
         eid => $context->{'current'}->{'eid'},
@@ -201,6 +205,10 @@ sub update {
 
     return $CELL->status_err( 'DOCHAZKA_MALFORMED_400' ) unless $self->{'iid'};
 
+    return $CELL->status_err( 
+        "DOCHAZKA_PARTIAL_INTERVAL_ILLEGAL_OPERATION" 
+    ) if $self->partial;
+
     my $status = cud( 
         conn => $context->{'dbix_conn'},
         eid => $context->{'current'}->{'eid'},
@@ -224,6 +232,10 @@ sub delete {
     my $self = shift;
     my ( $context ) = validate_pos( @_, { type => HASHREF } );
 
+    return $CELL->status_err( 
+        "DOCHAZKA_PARTIAL_INTERVAL_ILLEGAL_OPERATION" 
+    ) if $self->partial;
+
     my $status = cud( 
         conn => $context->{'dbix_conn'},
         eid => $context->{'current'}->{'eid'},
@@ -310,8 +322,7 @@ sub fetch_intervals_by_eid_and_tsrange {
         conn => $conn,
         class => __PACKAGE__,
         sql => $site->SQL_INTERVAL_SELECT_BY_EID_AND_TSRANGE_PARTIAL_INTERVALS,
-        keys => [ $eid, $tsrange,
-                  $eid, $tsrange, $site->DOCHAZKA_INTERVAL_SELECT_LIMIT ],
+        keys => [ $eid, $tsrange, $eid, $tsrange ],
     );
     return $status unless 
         ( $status->ok and $status->code eq 'DISPATCH_RECORDS_FOUND' ) or
@@ -326,10 +337,12 @@ sub fetch_intervals_by_eid_and_tsrange {
     
     my $result_set = $whole_intervals;
     push @$result_set, @$partial_intervals;
+    # But now the intervals are out of order
+    my @sorted_results = sort { $a->intvl cmp $b->intvl } @$result_set;
 
     if ( my $count = scalar @$result_set ) {
         return $CELL->status_ok( 'DISPATCH_RECORDS_FOUND', 
-            payload => $result_set, count => $count, args => [ $count ] );
+            payload => \@sorted_results, count => $count, args => [ $count ] );
     }
     return $CELL->status_notice( 'DISPATCH_NO_RECORDS_FOUND' );
 }
@@ -394,9 +407,9 @@ sub delete_intervals_by_eid_and_tsrange {
     # $status->payload contains [ $count ]
     my $count = $status->payload->[0];
 
-    # if it's more than the limit, no go
+    # if it's greater than or equal to the limit, no go
     return $CELL->status_err( 'DOCHAZKA_INTERVAL_DELETE_LIMIT_EXCEEDED', args => [ $count ] )
-        unless $count <= $site->DOCHAZKA_INTERVAL_DELETE_LIMIT;
+        if $count >= $site->DOCHAZKA_INTERVAL_DELETE_LIMIT;
     
     # hmm, can we use select_single with a DELETE statement?
     return cud_generic(
@@ -407,6 +420,7 @@ sub delete_intervals_by_eid_and_tsrange {
     );
 }
 
+
 =head1 AUTHOR
 
 Nathan Cutler, C<< <presnypreklad@gmail.com> >>
